@@ -1,5 +1,7 @@
 package IRC::Toolkit;
-our $VERSION = '0.02';
+{
+  $IRC::Toolkit::VERSION = '0.03';
+}
 
 use Carp;
 use strictures 1;
@@ -62,6 +64,12 @@ L<IRC::Toolkit::Modes>; Mode-line parsing tools
 
 L<IRC::Toolkit::Parser>; Functional interface to L<POE::Filter::IRCv3>
 
+=head1 SEE ALSO
+
+L<IRC::Utils>
+
+L<Parse::IRC>
+
 =head1 AUTHOR
 
 Jon Portnoy <avenj@cobaltirc.org>
